PaintTraversal

Struct PaintTraversal 

pub(crate) struct PaintTraversal<'a, Handler: PaintTraversalHandler> {
    handler: &'a mut Handler,
    outlines: Vec<(TraversalState, Arc<BoxFragment>)>,
    floats: Vec<(TraversalState, Arc<BoxFragment>)>,
}

Fields

handler: &'a mut Handleroutlines: Vec<(TraversalState, Arc<BoxFragment>)>floats: Vec<(TraversalState, Arc<BoxFragment>)>

Implementations

Source

impl<'a, Handler: PaintTraversalHandler> PaintTraversal<'a, Handler>

pub(crate) fn traverse( root_stacking_context: &StackingContext, handler: &'a mut Handler, )

fn traverse_stacking_context( &mut self, state: &TraversalState, stacking_context: &StackingContext, )

fn traverse_stacking_context_inner( &mut self, state: &TraversalState, root: &BoxFragmentWithStyle<'_>, )

fn traverse_stacking_container( &mut self, state: &TraversalState, root: &BoxFragmentWithStyle<'_>, is_block_level: bool, )

An implementation of https://drafts.csswg.org/css-position-4/#paint-a-stacking-context that only implements the parts relevant to stacking containers. This is an optimization to avoid work when descending into positioned container and stacking context contents.

fn traverse_block_level_descendants_decorations( &mut self, state: &TraversalState, fragment: &Fragment, ) -> bool

fn traverse_line_boxes_and_replaced_for_box( &mut self, state: &TraversalState, fragment: &BoxFragmentWithStyle<'_>, at_root_of_stacking_context: bool, )

fn traverse_line_boxes_and_replaced( &mut self, state: &TraversalState, fragment: &Fragment, at_root_of_stacking_context: bool, )

fn traverse_fragment_in_a_line_box( &mut self, state: &TraversalState, fragment: &Fragment, )

fn traverse_box_in_a_line_box( &mut self, state: &TraversalState, box_fragment: &BoxFragmentWithStyle<'_>, at_stacking_context_root: bool, )

fn traverse_replaced_content( &mut self, state: &TraversalState, box_fragment: &Arc<BoxFragment>, )

fn handle_box( &mut self, state: &TraversalState, fragment: &BoxFragmentWithStyle<'_>, )